@@ -24,7 +24,7 @@ class CanvasWidget : public KgDeclarativeView
 {
     Q_OBJECT
 public:
-    CanvasWidget(QWidget *parent = 0);
+    explicit CanvasWidget(QWidget *parent = 0);
     virtual ~CanvasWidget();
     KgThemeProvider *getProvider()
     {
